@@ -2,64 +2,64 @@
 function(f,para,...) {
     type <- para$type
     if(type == 'cau') {
-      return(quacau(f,para))
+      return(quacau(f,para,...))
     }
     else if(type == 'exp') {
-      return(quaexp(f,para))
+      return(quaexp(f,para,...))
     }
     else if(type == 'texp') {
-      return(quatexp(f,para))
+      return(quatexp(f,para,...))
     }
     else if(type == 'gam') {
-      return(quagam(f,para))
+      return(quagam(f,para,...))
     }
     else if(type == 'gev') {
-      return(quagev(f,para))
+      return(quagev(f,para,...))
     }
     else if(type == 'gld') {
       return(quagld(f,para,...))
     }
     else if(type == 'glo') {
-      return(quaglo(f,para))
+      return(quaglo(f,para,...))
     }
     else if(type == 'gno') {
-      return(quagno(f,para))
+      return(quagno(f,para,...))
     }
     else if(type == 'gpa') {
-      return(quagpa(f,para))
+      return(quagpa(f,para,...))
     }
     else if(type == 'gum') {
-      return(quagum(f,para))
+      return(quagum(f,para,...))
     }
     else if(type == 'kur') {
-      return(quakur(f,para))
+      return(quakur(f,para,...))
     }
     else if(type == 'ln3') {
-      return(qualn3(f,para))
+      return(qualn3(f,para,...))
     }
     else if(type == 'ray') {
-      return(quaray(f,para))
+      return(quaray(f,para,...))
     }
     else if(type == 'rice') {
-      return(quarice(f,para))
+      return(quarice(f,para,...))
     }
     else if(type == 'revgum') {
-      return(quarevgum(f,para))
+      return(quarevgum(f,para,...))
     }
     else if(type == 'kap') {
-      return(quakap(f,para))
+      return(quakap(f,para,...))
     }
     else if(type == 'nor') {
-      return(quanor(f,para))
+      return(quanor(f,para,...))
     }
     else if(type == 'pe3') {
-      return(quape3(f,para))
+      return(quape3(f,para,...))
     }
     else if(type == 'wak') {
-      return(quawak(f,para))
+      return(quawak(f,para,...))
     }
     else if(type == 'wei') {
-      return(quawei(f,para))
+      return(quawei(f,para,...))
     }
     else {
       stop("Did not find a valid distribution type")
